import copy
import os
import sys

from integration.partial.integration_test_utils import IntegrationTestUtils
from integration.test_suites.advisory_test_suite import BaseAdvisoryTestSuite


class FullTestAdvisory(BaseAdvisoryTestSuite.AdvisoryTestSuite):

    def set_expected_values(self):
        self.EXPECTED_EA_IMAGE_COUNT = 3
        self.EXPECTED_ETH_IMAGE_COUNT = 3
        self.EXPECTED_EA_SHAPE_COUNT = 6


    def setUp(self) -> None:

        self.set_expected_values()

        if IntegrationTestUtils.TEST_OUT_PATH is None or not os.path.isdir(IntegrationTestUtils.TEST_OUT_PATH):
        # if True:
            FullTestAdvisory.write_temp_run_config_files()
            FullTestAdvisory.run_dependent_pipelines()
            FullTestAdvisory.run_advisory_pipeline()
        else:
            string = f"output in {IntegrationTestUtils.TEST_OUT_PATH} already written, skipping rerun"
            print(string)
            i = 0


    @staticmethod
    def write_temp_run_config_files():
        default_config = IntegrationTestUtils.DEFAULT_CONFIG_FILE_PATH
        default_config_dict: dict = IntegrationTestUtils.load_json_file(default_config)
        run_dict: dict = copy.deepcopy(default_config_dict)
        run_dict['WorkspacePathout'] = IntegrationTestUtils.TEST_OUT_PATH
        run_dict['WorkspacePath'] = IntegrationTestUtils.TEST_OUT_PATH
        # we need to run the env suit pipeline as well
        run_dict['Environment']['WORK_PATH'] = IntegrationTestUtils.TEST_OUT_PATH
        run_dict['Environment']['INPUT_PATH'] = IntegrationTestUtils.TEST_OUT_PATH
        run_dict['Environment']['OUTPUT_PATH'] = IntegrationTestUtils.TEST_OUT_PATH

        #make sure we activate server download
        run_dict['Survey']['SkipServerDownload'] = False

        survey_cred_file: str = run_dict['Survey']['ServerCredentialsFile']
        run_dict['Survey']['ServerCredentialsFile'] = survey_cred_file.replace("Cred-ODK-EIAR.json", "Cred-ODK-EIAR-NO-WRSIS.json")
        run_dict['Survey']['FormEdits'].pop('WRSIS', None)

        # may be reusing a non-timestamped output file during development, so allow extant TEST_OUT_PATH
        os.makedirs(IntegrationTestUtils.TEST_OUT_PATH, exist_ok = True)
        IntegrationTestUtils.TEMP_CONFIG_FILE_NAME = IntegrationTestUtils.TEST_OUT_PATH + "temp_config.json"
        IntegrationTestUtils.write_json_file(run_dict, IntegrationTestUtils.TEMP_CONFIG_FILE_NAME)


    @staticmethod
    def run_dependent_pipelines():
        IntegrationTestUtils.run_external_pipeline("Deposition",
                                                   IntegrationTestUtils.TEST_START_DATE,
                                                   IntegrationTestUtils.EMAIL_CRED_PATH)
        IntegrationTestUtils.run_external_pipeline("Environment",
                                                   IntegrationTestUtils.TEST_START_DATE,
                                                   IntegrationTestUtils.EMAIL_CRED_PATH)

        previous_day_string: str = IntegrationTestUtils.get_day_before_as_string(IntegrationTestUtils.TEST_START_DATE)
        IntegrationTestUtils.run_external_pipeline("Survey",
                                                   previous_day_string,
                                                   IntegrationTestUtils.EMAIL_CRED_PATH)
        pass

    @staticmethod
    def run_advisory_pipeline():
        IntegrationTestUtils.run_external_pipeline(BaseAdvisoryTestSuite.AdvisoryTestSuite.ADVISORY_COMPONENT_NAME,
                                                   IntegrationTestUtils.TEST_START_DATE,
                                                   IntegrationTestUtils.EMAIL_CRED_PATH)


if __name__ == '__main__':
    _success: bool = IntegrationTestUtils.run_full_integration_test_pipeline(FullTestAdvisory,
                                                                             test_prefix = "advisory",
                                                                             processor_dir = BaseAdvisoryTestSuite.AdvisoryTestSuite.ADVISORY_PROCESSOR_DIR)
    if not _success:
        sys.exit(1)
